Documentation
¶
Overview ¶
(see github.com/uber-go/zap) with contexts.
Index ¶
- func Debug(ctx context.Context, msg string, fields ...zapcore.Field)
- func Error(ctx context.Context, msg string, fields ...zapcore.Field)
- func Info(ctx context.Context, msg string, fields ...zapcore.Field)
- func Logger(ctx context.Context) *zap.Logger
- func Warn(ctx context.Context, msg string, fields ...zapcore.Field)
- func WithFields(ctx context.Context, fields ...zapcore.Field) context.Context
- func WithLogger(ctx context.Context, logger *zap.Logger) context.Context
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Logger ¶
Logger returns the logger associated with the given context. If there is no context or no logger, it will panic.
func WithFields ¶
WithFields returns a new context derived from ctx that has a logger that always logs the given fields.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.